@@ -1,10 +1,11 @@
 import os
-XqeMh=Exception
-XqeMp=hasattr
+qOGLe=Exception
+qOGLs=hasattr
 from localstack import config
 from localstack.utils.aws import aws_stack
 from localstack.dashboard import infra as dashboard_infra
 from localstack.utils.common import short_uid,run_safe
+from localstack.utils.bootstrap import is_api_enabled
 from localstack_ext.utils.aws.aws_utils import MARKER_APIGW_REQUEST_REGION,THREAD_LOCAL
 from localstack_ext.bootstrap.aws_models import(RDSDatabase,RDSCluster,AppSyncAPI,AmplifyApp,ElastiCacheCluster,TransferServer,CloudFrontDistribution,CodeCommitRepository)
 get_graph_orig=dashboard_infra.get_graph
@@ -13,10 +14,12 @@ def get_resources(fetch_func):
   result=[]
   fetch_func(result)
   return result
- except XqeMh:
+ except qOGLe:
   pass
  return[]
 def get_rds_databases(name_filter,pool,env):
+ if not is_api_enabled('rds'):
+  return[]
  def fetch_func(result):
   client=aws_stack.connect_to_service('rds')
   dbs=client.describe_db_instances()
@@ -25,6 +28,8 @@ def get_rds_databases(name_filter,pool,env):
    result.append(obj)
  return get_resources(fetch_func)
 def get_rds_clusters(name_filter,pool,env):
+ if not is_api_enabled('rds'):
+  return[]
  def fetch_func(result):
   client=aws_stack.connect_to_service('rds')
   clusters=client.describe_db_clusters()
@@ -33,6 +38,8 @@ def get_rds_clusters(name_filter,pool,env):
    result.append(obj)
  return get_resources(fetch_func)
 def get_appsync_apis(name_filter,pool,env):
+ if not is_api_enabled('appsync'):
+  return[]
  def fetch_func(result):
   client=aws_stack.connect_to_service('appsync')
   apis=client.list_graphql_apis()
@@ -41,6 +48,8 @@ def get_appsync_apis(name_filter,pool,env):
    result.append(obj)
  return get_resources(fetch_func)
 def get_amplify_apps(name_filter,pool,env):
+ if not is_api_enabled('amplify'):
+  return[]
  def fetch_func(result):
   client=aws_stack.connect_to_service('amplify')
   apps=client.list_apps()
@@ -49,6 +58,8 @@ def get_amplify_apps(name_filter,pool,env):
    result.append(obj)
  return get_resources(fetch_func)
 def get_elasticache_clusters(name_filter,pool,env):
+ if not is_api_enabled('elasticache'):
+  return[]
  def fetch_func(result):
   client=aws_stack.connect_to_service('elasticache')
   clusters=client.describe_cache_clusters()
@@ -57,6 +68,8 @@ def get_elasticache_clusters(name_filter,pool,env):
    result.append(obj)
  return get_resources(fetch_func)
 def get_transfer_servers(name_filter,pool,env):
+ if not is_api_enabled('transfer'):
+  return[]
  def fetch_func(result):
   client=aws_stack.connect_to_service('transfer')
   servers=client.list_servers()
@@ -65,6 +78,8 @@ def get_transfer_servers(name_filter,pool,env):
    result.append(obj)
  return get_resources(fetch_func)
 def get_cloudfront_distributions(name_filter,pool,env):
+ if not is_api_enabled('cloudfront'):
+  return[]
  def fetch_func(result):
   client=aws_stack.connect_to_service('cloudfront')
   distros=client.list_distributions()
@@ -73,6 +88,8 @@ def get_cloudfront_distributions(name_filter,pool,env):
    result.append(obj)
  return get_resources(fetch_func)
 def get_codecommit_repos(name_filter,pool,env):
+ if not is_api_enabled('codecommit'):
+  return[]
  def fetch_func(result):
   client=aws_stack.connect_to_service('codecommit')
   repos=client.list_repositories()
@@ -83,7 +100,7 @@ def get_codecommit_repos(name_filter,pool,env):
 def get_graph(*args,**kwargs):
  os.environ['AWS_ACCESS_KEY_ID']=os.environ.get('AWS_ACCESS_KEY_ID')or 'foobar'
  os.environ['AWS_SECRET_ACCESS_KEY']=os.environ.get('AWS_SECRET_ACCESS_KEY')or 'foobar'
- if XqeMp(THREAD_LOCAL,'request_context'):
+ if qOGLs(THREAD_LOCAL,'request_context'):
   region=kwargs.get('region')or config.DEFAULT_REGION
   THREAD_LOCAL.request_context.headers[MARKER_APIGW_REQUEST_REGION]=region
  result=run_safe(get_graph_orig,*args,**kwargs)or{'nodes':[],'edges':[]}
