@@ -1,26 +1,26 @@
 #!/usr/bin/env python
-rCHkj=dict
-rCHkL=super
-rCHkp=hasattr
-rCHkT=Exception
-rCHka=object
-rCHkI=dir
-rCHkW=None
-rCHkB=False
-rCHkl=True
-rCHky=len
-rCHkb=set
+GibsF=dict
+Gibsw=super
+GibsS=hasattr
+GibsU=Exception
+Gibsc=object
+Gibsg=dir
+Gibst=None
+Gibsp=False
+Gibsf=True
+GibsJ=len
+Gibsx=set
 import errno
 import socket
 from select import select
 from socket import(AF_INET,AF_INET6,SOCK_STREAM,IPV6_V6ONLY,SO_REUSEADDR,IPPROTO_TCP,IPPROTO_IPV6,TCP_NODELAY,SOL_SOCKET)
-class AttrDict(rCHkj):
+class AttrDict(GibsF):
  def __init__(self,*args,**kwargs):
-  rCHkL(AttrDict,self).__init__(*args,**kwargs)
+  Gibsw(AttrDict,self).__init__(*args,**kwargs)
   self.__dict__=self
 def tcp_listen(six,addr,port,blk):
  s=socket.socket(AF_INET6 if six else AF_INET,SOCK_STREAM)
- if six and rCHkp(socket,'IPV6_V6ONLY'):
+ if six and GibsS(socket,'IPV6_V6ONLY'):
   s.setsockopt(IPPROTO_IPV6,IPV6_V6ONLY,0)
  s.setsockopt(SOL_SOCKET,SO_REUSEADDR,1)
  s.setsockopt(IPPROTO_TCP,TCP_NODELAY,1)
@@ -37,9 +37,9 @@ def tcp_connect(six,addr,port,blk):
 def safe_close(x):
  try:
   x.close()
- except rCHkT:
+ except GibsU:
   pass
-class Server(rCHka):
+class Server(Gibsc):
  def __init__(self,opt,q):
   self.opt=opt
   self.sock=tcp_listen(opt.ip6,opt.bind_addr,opt.bind_port,0)
@@ -51,17 +51,17 @@ class Server(rCHka):
    cl,addr=self.sock.accept()
    cl.setblocking(0)
    self.q.append(Proxy(self.opt,cl,addr))
-class Half(rCHka):
- def __init__(self,opt,sock,addr,rCHkI):
+class Half(Gibsc):
+ def __init__(self,opt,sock,addr,Gibsg):
   self.opt=opt
   self.sock=sock
   self.addr=addr
-  self.rCHkI=rCHkI
-  self.name='peer' if self.rCHkI else 'client'
+  self.Gibsg=Gibsg
+  self.name='peer' if self.Gibsg else 'client'
   self.queue=[]
-  self.dest=rCHkW
-  self.err=rCHkW
-  self.ready=rCHkB
+  self.dest=Gibst
+  self.err=Gibst
+  self.ready=Gibsp
  def pre_wait(self,rr,r,w,e):
   if self.ready:
    rr.append(self.sock)
@@ -72,7 +72,7 @@ class Half(rCHka):
   if not self.err and self.sock in w and self.queue:
    self.write_some()
   if not self.err and self.sock in r:
-   self.ready=rCHkl
+   self.ready=Gibsf
    self.copy()
   return self.err
  def error(self,msg,e):
@@ -81,9 +81,9 @@ class Half(rCHka):
  def write_some(self):
   try:
    n=self.sock.send(self.queue[0])
-  except rCHkT as e:
+  except GibsU as e:
    return self.error('send error',e)
-  if n!=rCHky(self.queue[0]):
+  if n!=GibsJ(self.queue[0]):
    self.queue[0]=self.queue[0][n:]
   else:
    del self.queue[0]
@@ -92,17 +92,17 @@ class Half(rCHka):
    buf=self.sock.recv(4096)
   except socket.error as e:
    if e.errno==errno.EWOULDBLOCK:
-    self.ready=rCHkB
+    self.ready=Gibsp
     return
    return self.error('recv socket error',e)
-  except rCHkT as e:
+  except GibsU as e:
    return self.error('recv error',e)
-  if rCHky(buf)==0:
+  if GibsJ(buf)==0:
    return self.error('eof',0)
   self.dest.queue.append(buf)
  def close(self):
   safe_close(self.sock)
-class Proxy(rCHka):
+class Proxy(Gibsc):
  def __init__(self,opt,sock,addr):
   self.opt=opt
   self.cl=Half(opt,sock,addr,'i')
@@ -110,7 +110,7 @@ class Proxy(rCHka):
   self.peer=Half(opt,peer,addr,'o')
   self.cl.dest=self.peer
   self.peer.dest=self.cl
-  self.err=rCHkW
+  self.err=Gibst
  def pre_wait(self,rr,r,w,e):
   self.cl.pre_wait(rr,r,w,e)
   self.peer.pre_wait(rr,r,w,e)
@@ -125,7 +125,7 @@ class Proxy(rCHka):
   return self.err
 def server_loop(opt):
  qs=[]
- opt['ip6']=opt.get('ip6',rCHkB)
+ opt['ip6']=opt.get('ip6',Gibsp)
  opt['bind_addr']=opt.get('bind_addr','0.0.0.0')
  opt['addr']=opt.get('addr','127.0.0.1')
  opt['bind_port']=opt.get('bind_port',0)
@@ -137,15 +137,15 @@ def server_loop(opt):
    q.pre_wait(rr,r,w,e)
   timeo=10.0 if not rr else 0.0
   r,w,e=select(r,w,e,timeo)
-  r=rCHkb(r).union(rr)
+  r=Gibsx(r).union(rr)
   for q in qs:
    if q.post_wait(r,w,e):
     qs.remove(q)
 def main():
- opt={'ip6':rCHkB,'bind_port':2223,'addr':'192.168.43.191','port':22}
- opt={'ip6':rCHkB,'bind_port':48429,'addr':'128.0.100.3','port':22}
- opt={'ip6':rCHkB,'port':54237,'bind_addr':'128.0.100.2','bind_port':22}
- opt={'ip6':rCHkB,'port':54237,'bind_addr':'192.168.100.3','bind_port':22}
+ opt={'ip6':Gibsp,'bind_port':2223,'addr':'192.168.43.191','port':22}
+ opt={'ip6':Gibsp,'bind_port':48429,'addr':'128.0.100.3','port':22}
+ opt={'ip6':Gibsp,'port':54237,'bind_addr':'128.0.100.2','bind_port':22}
+ opt={'ip6':Gibsp,'port':54237,'bind_addr':'192.168.100.3','bind_port':22}
  server_loop(opt)
 if __name__=='__main__':
  main()
