@@ -20,11 +20,13 @@ API_PATH_SIGNUP = '%s/signup' % API_PATH_USER
 API_PATH_RECOVER = '%s/recover' % API_PATH_USER
 API_PATH_RESEND = '%s/resend' % API_PATH_USER
 API_PATH_ACTIVATE = '%s/activate' % API_PATH_USER
+API_PATH_UNSUBSCRIBE = '%s/unsubscribe' % API_PATH_USER
 API_PATH_KEY_ACTIVATE = '%s/activate' % API_PATH
 API_PATH_CARDS = '%s/cards' % API_PATH_USER
 API_PATH_PLANS = '%s/plans' % API_PATH
 API_PATH_SUBSCRIPTIONS = '%s/subscriptions' % API_PATH_PLANS
 API_PATH_INVOICES = '%s/invoices' % API_PATH_PLANS
+API_PATH_CLOUDPODS = '%s/cloudpods' % API_PATH
 API_PATH_EVENTS = '%s/events' % API_PATH
 API_PATH_STATS = '%s/stats' % API_PATH_EVENTS
 API_PATH_GITHUB = '%s/github' % API_PATH
@@ -66,6 +68,9 @@ SMTP_EMAIL = os.environ.get('SMTP_EMAIL', '')
 # whether to automatically start up utility containers (e.g., Spark/Hadoop for EMR, Presto for Athena)
 AUTOSTART_UTIL_CONTAINERS = localstack_config.is_env_true('AUTOSTART_UTIL_CONTAINERS')
 
+# optional flags to pass when starting the bigdata Docker container
+BIGDATA_DOCKER_FLAGS = os.environ.get('BIGDATA_DOCKER_FLAGS', '')
+
 # Comma-separated list of regex patterns for DNS names to resolve locally.
 # Any DNS name not matched against any of the patterns on this whitelist
 # will resolve to the real DNS entry, rather than the local one.
@@ -97,9 +102,11 @@ DEFAULT_PORT_LOCAL_DAEMON = 4535
 DEFAULT_PORT_LOCAL_DAEMON_ROOT = 4534
 
 # port ranges for service instances (e.g., Postgres DBs, ElastiCache clusters, ...)
-SERVICE_INSTANCES_PORTS_START = 4510
-SERVICE_INSTANCES_PORTS_END = SERVICE_INSTANCES_PORTS_START + 20
+SERVICE_INSTANCES_PORTS_START = int(os.environ.get('SERVICE_INSTANCES_PORTS_START') or 4510)
+SERVICE_INSTANCES_PORTS_END = int(os.environ.get('SERVICE_INSTANCES_PORTS_END') or
+    (SERVICE_INSTANCES_PORTS_START + 30))
 
+# port for Azure APIs
 PORT_AZURE = 12121
 
 # add default service ports (TODO needed?)
@@ -108,9 +115,10 @@ localstack_constants.DEFAULT_SERVICE_PORTS['azure'] = PORT_AZURE
 # Docker host name resolvable from containers
 DOCKER_HOST_NAME = 'host.docker.internal'
 
-# Port where Hive/metastore is available for EMR/Athena
+# Port where Hive/metastore/Spark are available for EMR/Athena
 PORT_HIVE_METASTORE = 9083
 PORT_HIVE_SERVER = 10000
+PORT_SPARK_MASTER = 7077
 
 if localstack_config.DOCKER_HOST_FROM_CONTAINER == DOCKER_HOST_NAME:
     # special case when we're running tests outside of Docker
@@ -132,7 +140,7 @@ if localstack_config.DOCKER_HOST_FROM_CONTAINER == DOCKER_HOST_NAME:
 localstack_config.CONFIG_ENV_VARS += [
     'SMTP_HOST', 'SMTP_USER', 'SMTP_PASS', 'SMTP_EMAIL', 'DNS_SERVER', 'DNS_ADDRESS', 'ENFORCE_IAM',
     'DNS_RESOLVE_IP', 'DNS_LOCAL_NAME_PATTERNS', 'AUTOSTART_UTIL_CONTAINERS', 'CLOUDFRONT_STATIC_PORTS',
-    'REQUIRE_PRO', 'AZURE'
+    'REQUIRE_PRO', 'AZURE', 'BIGDATA_DOCKER_FLAGS'
 ]
 
 # re-initialize configs in localstack
